<!DOCTYPE html>
<html lang="en">
<head>
    {% load static %}
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1" />
    <link rel="stylesheet" href="{% static 'soccerpoll/styles.css' %}">
    <title>Soccer Poll - Powered Omar Abraham</title>
</head>
<body>
    <div style="text-align: center;">
        <h1>Hello, you're at Soccer Polls home page ...</h1>
    </div>
    {% if hello_info %}
        <p>{{ hello_info }}</p>
    {% endif %}
    {% if fibo_seq %}
        <ul><li><b>{{ fibo_seq }}</b></li></ul>
    {% endif %}
    {% if prime_nums_txt %}
        <p>{{ prime_nums_txt }}</p>
        <ul><li><b>{{ prime_nums }}</b></li></ul>
    {% endif %}
    <h2>World survey - 2025:</h2>
    {% if latest_q_list %}
        <ul>
        {% for q in latest_q_list %}
            <li><a href="{% url 'soccerpoll:detail' q.id %}">{{ q.text }}</a></li>
        {% endfor %}
        </ul>
    {% else %}
        <p>No Soccer polls are available ...</p>
    {% endif %}
    <a href="/admin">Admin console</a></li>
</body>
</html>