# Generated by Django 6.0 on 2025-12-08 00:06
import django.db.models.deletion
import django.utils.timezone
from django.db import migrations, models

class Migration(migrations.Migration):

    initial = True
    DATE_PUBLISHED='Date Published'
    SPOLL_QUESTION='soccerpoll.question'
    SPOLL_COUNTRY='soccerpoll.country'
    dependencies = []

    operations = [
        migrations.CreateModel(
            name='Country',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='Mexico', max_length=200, unique=True)),
                ('abbreviation', models.CharField(default='MX', max_length=200)),
                ('pub_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name=DATE_PUBLISHED)),
            ],
        ),
        migrations.CreateModel(
            name='Question',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.CharField(max_length=200, verbose_name='Question')),
                ('pub_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name=DATE_PUBLISHED)),
            ],
        ),
        migrations.CreateModel(
            name='QuestionType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='player', max_length=50, unique=True)),
                ('pub_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name=DATE_PUBLISHED)),
            ],
        ),
        migrations.CreateModel(
            name='TeamType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='league', max_length=50, unique=True)),
                ('pub_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name=DATE_PUBLISHED)),
            ],
        ),
        migrations.CreateModel(
            name='Coach',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('age', models.IntegerField(default=0)),
                ('nickname', models.CharField(max_length=100)),
                ('pub_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name=DATE_PUBLISHED)),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to=SPOLL_COUNTRY)),
            ],
        ),
        migrations.CreateModel(
            name='Player',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('age', models.IntegerField(default=0)),
                ('nickname', models.CharField(max_length=100)),
                ('pub_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name=DATE_PUBLISHED)),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to=SPOLL_COUNTRY)),
            ],
        ),
        migrations.CreateModel(
            name='PlayerChoice',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('votes', models.IntegerField(default=0)),
                ('pub_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name=DATE_PUBLISHED)),
                ('choice', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='soccerpoll.player')),
                ('question', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=SPOLL_QUESTION)),
            ],
        ),
        migrations.CreateModel(
            name='CoachChoice',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('votes', models.IntegerField(default=0)),
                ('pub_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name=DATE_PUBLISHED)),
                ('choice', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='soccerpoll.coach')),
                ('question', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=SPOLL_QUESTION)),
            ],
        ),
        migrations.AddField(
            model_name='question',
            name='type',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.DO_NOTHING, to='soccerpoll.questiontype'),
        ),
        migrations.CreateModel(
            name='Team',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('nickname', models.CharField(max_length=100)),
                ('age', models.IntegerField(default=0)),
                ('uniform_color_local', models.CharField(default='#FFFFFF', max_length=100)),
                ('uniform_color_visitant', models.CharField(default='#000000', max_length=100)),
                ('pub_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name=DATE_PUBLISHED)),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to=SPOLL_COUNTRY)),
                ('type', models.ForeignKey(default=1, on_delete=django.db.models.deletion.DO_NOTHING, to='soccerpoll.teamtype')),
            ],
        ),
        migrations.CreateModel(
            name='TeamChoice',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('votes', models.IntegerField(default=0)),
                ('pub_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name=DATE_PUBLISHED)),
                ('choice', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='soccerpoll.team')),
                ('question', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=SPOLL_QUESTION)),
            ],
        ),
    ]
